[sr-dev] git:master: fixed spelling errors catched by lintian

Victor Seva linuxmaniac at torreviejawireless.org
Tue Aug 20 11:19:05 CEST 2013


Module: sip-router
Branch: master
Commit: c86b04459a716af353d0ca40a793d6b13c6a6fe7
URL:    http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=c86b04459a716af353d0ca40a793d6b13c6a6fe7

Author: Victor Seva <linuxmaniac at torreviejawireless.org>
Committer: Victor Seva <linuxmaniac at torreviejawireless.org>
Date:   Tue Aug 20 10:24:53 2013 +0200

fixed spelling errors catched by lintian

---

 modules/cdp/diameter_peer.c                   |    4 ++--
 modules/ims_auth/authims_mod.c                |    2 +-
 modules/ims_auth/authorize.c                  |    4 ++--
 modules/ims_auth/doc/ims_auth_admin.xml       |    2 +-
 modules/ims_icscf/db.c                        |    2 +-
 modules/ims_isc/mark.c                        |    2 +-
 modules/iptrtpproxy/doc/iptrtpproxy_admin.xml |    2 +-
 modules/mangler/contact_ops.c                 |    2 +-
 modules/presence/event_list.c                 |    2 +-
 modules/presence/hash.c                       |    2 +-
 modules/pua_mi/mi_func.c                      |    4 ++--
 modules/uid_avp_db/uid_avp_db.c               |    4 ++--
 modules/xhttp_pi/xhttp_pi_fnc.c               |    2 +-
 utils/kamctl/kamctl.8                         |   14 +++++++-------
 14 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/modules/ims_auth/authims_mod.c b/modules/ims_auth/authims_mod.c
index a23e7ce..b245d85 100644
--- a/modules/ims_auth/authims_mod.c
+++ b/modules/ims_auth/authims_mod.c
@@ -110,7 +110,7 @@ str cxdx_forced_peer;
 /* fixed parameter storage */
 str scscf_name_str; /**< fixed name of the S-CSCF 							*/
 
-/* used mainly in testing - load balancing with SIPP where we dont want to worry about auth */
+/* used mainly in testing - load balancing with SIPP where we don't want to worry about auth */
 int ignore_failed_auth = 0;
 
 /*
diff --git a/modules/ims_auth/authorize.c b/modules/ims_auth/authorize.c
index 9f58554..026e3b5 100644
--- a/modules/ims_auth/authorize.c
+++ b/modules/ims_auth/authorize.c
@@ -666,7 +666,7 @@ int authenticate(struct sip_msg* msg, char* _realm, char* str2, int is_proxy_aut
         LM_ERR("no matching auth vector found - maybe timer expired\n");
 
         if (ignore_failed_auth) {
-            LM_WARN("NB: Ignoring all failed auth - check your config if you dont expect this\n");
+            LM_WARN("NB: Ignoring all failed auth - check your config if you don't expect this\n");
             ret = AUTH_OK;
         }
 
@@ -801,7 +801,7 @@ int authenticate(struct sip_msg* msg, char* _realm, char* str2, int is_proxy_aut
     }
 
     if (ignore_failed_auth) {
-        LM_WARN("NB: Ignoring all failed auth - check your config if you dont expect this\n");
+        LM_WARN("NB: Ignoring all failed auth - check your config if you don't expect this\n");
         ret = AUTH_OK;
     }
 
diff --git a/modules/ims_auth/doc/ims_auth_admin.xml b/modules/ims_auth/doc/ims_auth_admin.xml
index 3357cc9..240c3ef 100644
--- a/modules/ims_auth/doc/ims_auth_admin.xml
+++ b/modules/ims_auth/doc/ims_auth_admin.xml
@@ -296,7 +296,7 @@ modparam("ims_auth", "add_authinfo_hdr", 0)
       <title><varname>ignore_failed_auth</varname> (integer)</title>
 
       <para>Ignore invalid passwords (only IMPI/IMPU is checked).</para>
-      <para>It should be used only for testing, e.g. load balancing with SIPP where we dont want to worry about auth.</para>
+      <para>It should be used only for testing, e.g. load balancing with SIPP where we don't want to worry about auth.</para>
 
       <para>Default value is <quote>0</quote> (don't ingnore the failed authentication).</para>
 
diff --git a/modules/ims_icscf/db.c b/modules/ims_icscf/db.c
index 343d92d..05c81ad 100644
--- a/modules/ims_icscf/db.c
+++ b/modules/ims_icscf/db.c
@@ -343,7 +343,7 @@ int ims_icscf_db_get_capabilities(scscf_capabilities *cap[],int cap_cnt)
 	}
 
 	if (res->n == 0) {
-		LM_DBG("DBG:ims_icscf_db_get_capabilities: No Capabilites found... not critical...\n");
+		LM_DBG("DBG:ims_icscf_db_get_capabilities: No Capabilities found... not critical...\n");
 		return 1;
 	}
 	else {
diff --git a/modules/ims_isc/mark.c b/modules/ims_isc/mark.c
index e13593b..470a20d 100644
--- a/modules/ims_isc/mark.c
+++ b/modules/ims_isc/mark.c
@@ -165,7 +165,7 @@ void isc_mark_get(str x, isc_mark *mark) {
 				}
 				break;
 			default:
-				LM_ERR("isc_mark_get: unkown parameter found: %c !\n", x.s[i]);
+				LM_ERR("isc_mark_get: unknown parameter found: %c !\n", x.s[i]);
 			}
 			i = j + 1;
 		} else
diff --git a/modules/iptrtpproxy/doc/iptrtpproxy_admin.xml b/modules/iptrtpproxy/doc/iptrtpproxy_admin.xml
index b17b0a0..593d6a2 100644
--- a/modules/iptrtpproxy/doc/iptrtpproxy_admin.xml
+++ b/modules/iptrtpproxy/doc/iptrtpproxy_admin.xml
@@ -27,7 +27,7 @@
 
 	<para>
 	This &kamailio; module is written as a light-weight module, there is no 
-	dialog managment as in <emphasis>Nathelper</emphasis>. The reason is that such an API
+	dialog management as in <emphasis>Nathelper</emphasis>. The reason is that such an API
 	should be provided by core or a specialized dialog manager module.
 	Because such module is not in git, session information may be stored 
 	in extra attributes of the <emphasis>avp_db</emphasis> module and
diff --git a/modules/mangler/contact_ops.c b/modules/mangler/contact_ops.c
index c39f8f6..bdde099 100644
--- a/modules/mangler/contact_ops.c
+++ b/modules/mangler/contact_ops.c
@@ -369,7 +369,7 @@ encode2format (struct sip_msg* msg, str* uri, struct uri_format *format)
 				format->rcv_proto=s_sctp;
 				break;
 			default:
-				BUG("unkown proto %d\n", msg->rcv.proto);
+				BUG("unknown proto %d\n", msg->rcv.proto);
 		}
 	}else{
 		format->rcv_proto.s=0;
diff --git a/modules/presence/event_list.c b/modules/presence/event_list.c
index ee272c1..ece09a0 100644
--- a/modules/presence/event_list.c
+++ b/modules/presence/event_list.c
@@ -255,7 +255,7 @@ int add_event(pres_ev_t* event)
 	}
 	EvList->ev_count++;
 	
-	LM_DBG("succesfully added event: %.*s - len= %d\n",ev->name.len,
+	LM_DBG("successfully added event: %.*s - len= %d\n",ev->name.len,
 			ev->name.s, ev->name.len);
 done:
 	free_event_params(parsed_event.params.list, PKG_MEM_TYPE);
diff --git a/modules/presence/hash.c b/modules/presence/hash.c
index c7d366a..de7f08f 100644
--- a/modules/presence/hash.c
+++ b/modules/presence/hash.c
@@ -634,7 +634,7 @@ int update_phtable(presentity_t* presentity, str pres_uri, str body)
 	if(presentity->event->get_rules_doc(&presentity->user, &presentity->domain,
 				&xcap_doc)< 0)
 	{
-		LM_ERR("failed to retreive xcap document\n");
+		LM_ERR("failed to retrieve xcap document\n");
 		ret= -1;
 		goto done;
 	}
diff --git a/modules/pua_mi/mi_func.c b/modules/pua_mi/mi_func.c
index 6343f61..d0061de 100644
--- a/modules/pua_mi/mi_func.c
+++ b/modules/pua_mi/mi_func.c
@@ -220,7 +220,7 @@ struct mi_root* mi_pua_publish(struct mi_root* cmd, void* param)
 	publ.event= get_event_flag(&event);
 	if(publ.event< 0)
 	{
-		LM_ERR("unkown event\n");
+		LM_ERR("unknown event\n");
 		return init_mi_tree(400, "Unknown event", 13);
 	}
 	if(content_type.len!= 1)
@@ -461,7 +461,7 @@ struct mi_root* mi_pua_subscribe(struct mi_root* cmd, void* param)
 	subs.event= get_event_flag(&event);
 	if(subs.event< 0)
 	{
-		LM_ERR("unkown event\n");
+		LM_ERR("unknown event\n");
 		return init_mi_tree(400, "Unknown event", 13);
 	}
 
diff --git a/modules/uid_avp_db/uid_avp_db.c b/modules/uid_avp_db/uid_avp_db.c
index 5d3b5e4..7970740 100644
--- a/modules/uid_avp_db/uid_avp_db.c
+++ b/modules/uid_avp_db/uid_avp_db.c
@@ -285,7 +285,7 @@ static int load_uri_attrs(struct sip_msg* msg, unsigned long flags, fparam_t* fp
     uri_type_to_str(puri.type, &(load_uri_attrs_cmd->match[2].v.lstr));
 
 	if (db_exec(&res, load_uri_attrs_cmd) < 0) {
-		ERR("Error while quering database\n");
+		ERR("Error while querying database\n");
 		return -1;
     }
     
@@ -307,7 +307,7 @@ static int load_user_attrs(struct sip_msg* msg, unsigned long flags, fparam_t* f
 	}
 
 	if (db_exec(&res, load_user_attrs_cmd) < 0) {
-		ERR("Error while quering database\n");
+		ERR("Error while querying database\n");
 		return -1;
     }
     
diff --git a/modules/xhttp_pi/xhttp_pi_fnc.c b/modules/xhttp_pi/xhttp_pi_fnc.c
index b822e8a..761a277 100644
--- a/modules/xhttp_pi/xhttp_pi_fnc.c
+++ b/modules/xhttp_pi/xhttp_pi_fnc.c
@@ -2498,7 +2498,7 @@ int getVal(db_val_t *val, db_type_t val_type, db_key_t key, ph_db_table_t *table
 			LM_DBG("[%.*s] has flags [%d]\n", key->len, key->s, flags);
 			if(flags){
 				XHTTP_PI_BUILD_REPLY(ctx,
-					"Unkown validation [%d] for %s.",
+					"Unknown validation [%d] for %s.",
 					table->cols[i].validation, key->s);
 				goto done;
 			}
diff --git a/utils/kamctl/kamctl.8 b/utils/kamctl/kamctl.8
index 83db5d7..f0d225e 100644
--- a/utils/kamctl/kamctl.8
+++ b/utils/kamctl/kamctl.8
@@ -43,7 +43,7 @@ Ping <uri> with SIP OPTIONS
 
 
 .TP 16
-.I Access control list (acl)  managment commands:
+.I Access control list (acl)  management commands:
 .TP
 .B acl show [<username>]
 Show user membership
@@ -55,7 +55,7 @@ Grant user membership (*)
 Grant user membership(s) (*)
 
 .TP 16
-.I  Least cost routes (lcr) managment command:
+.I  Least cost routes (lcr) management command:
 .TP             
 .B lcr dump
 Show in memory gateways and routes tables
@@ -64,7 +64,7 @@ Show in memory gateways and routes tables
 Reload lcr gateways and routes
 
 .TP 16
-.I Carrierroute tables('cr') managment commands:
+.I Carrierroute tables('cr') management commands:
 .TP
 .B cr show 
 Show tables
@@ -88,7 +88,7 @@ Add a carrier (prob, strip, rewrite_prefix, rewrite_suffix, flags, mask and comm
 Remove a carrier
 
 .TP 16
-.I Remote-Party-ID (RPID) managment commands:
+.I Remote-Party-ID (RPID) management commands:
 .TP
 .B rpid add <username> <rpid>
 Add rpid for a user (*)
@@ -100,7 +100,7 @@ Set rpid to NULL for a user (*)
 Show rpid of a user
 
 .TP 16
-.I Subscriber managment commands:
+.I Subscriber management commands:
 .TP
 .B add <username> <password> 
  Add a new subscriber (*)
@@ -130,7 +130,7 @@ Add a new entry (from_pattern and tag are optional arguments)
 Remove all entres for the given src_ip
 
 .TP 16
-.I Dispatcher managment commands:
+.I Dispatcher management commands:
 .TP
 .B dispatcher show 
 Show dispatcher gateways
@@ -154,7 +154,7 @@ Delete gateway
 Restart phone configured for <uri>
 
 .TP 16
-.I User location('ul') or aliases managment commands:
+.I User location('ul') or aliases management commands:
 .B ul show [<username>]
 Show in-RAM online users
 .TP




More information about the sr-dev mailing list
diff --git a/modules/cdp/diameter_peer.c b/modules/cdp/diameter_peer.c
index 4c01bb4..ce86e1a 100644
--- a/modules/cdp/diameter_peer.c
+++ b/modules/cdp/diameter_peer.c
@@ -417,8 +417,8 @@ void diameter_peer_destroy()
 		lock_release(shutdownx_lock);
 	}
 
-	/* wait for all childs to clean up nicely (acceptor, receiver, timer, workers) */
-	LM_INFO("destroy_diameter_peer(): Terminating all childs...\n");
+	/* wait for all children to clean up nicely (acceptor, receiver, timer, workers) */
+	LM_INFO("destroy_diameter_peer(): Terminating all children...\n");
 	while(pid_list->tail){
 		pid = dp_last_pid();
 		if (pid<=0||pid==getpid()){